@@ -17,9 +17,6 @@ if PY2:
     # TYPE is used in exceptions, repr(int) is different on Python 2 and 3.
     TYPE = "type"
 
-    def exec_(code, locals_, globals_):
-        exec("exec code in locals_, globals_")
-
     def iteritems(d):
         return d.iteritems()
 
@@ -31,9 +28,6 @@ else:
 
     TYPE = "class"
 
-    def exec_(code, locals_, globals_):
-        exec(code, locals_, globals_)
-
     def iteritems(d):
         return d.items()
 
